# Define pkgdocdir for releases that don't define it already
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}
%{!?ruby_vendorlibdir: %global ruby_vendorlibdir %(ruby -rrbconfig -e 'puts RbConfig::CONFIG["sitelibdir"]')}
%{!?ruby_vendorarchdir: %global ruby_vendorarchdir %(ruby -rrbconfig -e 'puts RbConfig::CONFIG["sitearchdir"]')}

# We ship a .pc file but don't need to depend on pkg-config
%global __requires_exclude pkg-config
%global __provides_exclude_from ^(%{python_sitearch}/.*\\.so|%{_libdir}/.libqmf*)$

Name:    qpid-qmf
Version: 0.26
Release: 2%{?dist}
Summary: The QPID Management Framework
License: ASL 2.0
URL:     http://qpid.apache.org

ExcludeArch: ppc64

Source0: http://www.apache.org/dist/qpid/%{version}/qpid-%{version}.tar.gz
Patch01: 0001-NO-JIRA-qpidd.service-file-for-use-on-Fedora.patch
Patch02: 0002-QPID-4984-Fix-for-recovery-ambiguity-issue-other-cod.patch
Patch03: 0003-QPID-5556-Provide-the-right-Perl-packages-in-top-lev.patch
Patch04: 0004-QPID-5499-Fix-Ruby-Perl-bindings-when-built-with-Wer.patch
Patch05: 0005-QPID-5656-Updated-Ruby-bindings-to-build-under-CMake.patch
Patch06: 0006-QPID-5718-Dead-code-in-the-HA-codebase.patch
Patch07: 0007-NO-JIRA-Remove-dead-code.patch

BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: swig
BuildRequires: python2-devel
BuildRequires: ruby
BuildRequires: ruby-devel
BuildRequires: boost-devel
BuildRequires: libuuid-devel

Requires:  qpid-cpp-client%{?_isa} >= %{version}
Requires:  python-qpid >= %{version}
Requires:  python-qpid-qmf%{?_isa} = %{version}


%description
The Qpid Management Framework is a general-purpose management bus built on Qpid
messaging. It takes advantage of the scalability, security, and rich
capabilities of Qpid to provide flexible and easy-to-use manageability to a
large set of applications.



%package devel
Summary:   Header files and tools for developing QMF extensions

Requires:  qpid-qmf%{?_isa} = %{version}-%{release}
Requires:  qpid-cpp-client-devel%{?_isa} >= %{version}

%description devel
Header files and code-generation tools needed for developers of QMF-managed
components.

%files devel
%{_libdir}/libqmf2.so
%{_bindir}/qmf-gen
%{python_sitelib}/qmfgen
%{_libdir}/pkgconfig/qmf2.pc

%post devel -p /sbin/ldconfig

%postun devel -p /sbin/ldconfig



%package -n python-qpid-qmf
Summary:   The QPID Management Framework bindings for python

Requires:  qpid-qmf%{?_isa} = %{version}-%{release}


%description -n python-qpid-qmf
An extensible management framework layered on QPID messaging, bindings
for python.

%files -n python-qpid-qmf
%{python_sitelib}/qpidtoollibs
%{python_sitearch}/qmf
%{python_sitearch}/qmf2.py*
%{python_sitearch}/cqmf2.py*
%{python_sitearch}/_cqmf2.so

%post -n python-qpid-qmf -p /sbin/ldconfig

%postun -n python-qpid-qmf -p /sbin/ldconfig



%package -n ruby-qpid-qmf
Summary:   The QPID Management Framework bindings for ruby

Requires:  qpid-qmf%{?_isa} = %{version}-%{release}


%description -n ruby-qpid-qmf
An extensible management framework layered on QPID messaging, bindings
for ruby.

%files -n ruby-qpid-qmf
# %{ruby_vendorlibdir}/qmf.rb
%{ruby_vendorlibdir}/qmf2.rb
%{ruby_vendorarchdir}/cqpid.so
%{ruby_vendorarchdir}/cqmf2.so

%post -n ruby-qpid-qmf -p /sbin/ldconfig

%postun -n ruby-qpid-qmf -p /sbin/ldconfig


%files -n qpid-qmf
%{_bindir}/qmf-tool
%{_libdir}/libqmf2.so.*
%doc %{_pkgdocdir}

%post -n qpid-qmf -p /sbin/ldconfig

%postun -n qpid-qmf -p /sbin/ldconfig



%prep
%setup -q -n qpid-%{version}

%patch01 -p2
%patch02 -p2
%patch03 -p2
%patch04 -p2
%patch05 -p2
%patch06 -p2
%patch07 -p2

%global perftests "qpid-perftest qpid-topic-listener qpid-topic-publisher qpid-latency-test qpid-client-test qpid-txtest"

%global rh_qpid_tests_failover "failover_soak run_failover_soak"

%global rh_qpid_tests_clients "replaying_sender resuming_receiver declare_queues"


%build
pushd cpp
%cmake -DDOC_INSTALL_DIR:PATH=%{_pkgdocdir} .
make %{?_smp_mflags}

pushd ../python
./setup.py build
popd
pushd ../tools
./setup.py build
popd
pushd ../extras/qmf
./setup.py build
popd

popd

%install
mkdir -p -m0755 %{buildroot}/%{_bindir}
mkdir -p -m0755 %{buildroot}/%{_unitdir}

pushd python
%{__python} setup.py install \
   --skip-build \
   --install-purelib %{python_sitearch} \
   --root %{buildroot}
popd

pushd tools
%{__python} setup.py install \
    --skip-build \
    --install-purelib %{python_sitelib} \
    --root %{buildroot}
popd

pushd extras/qmf
%{__python} setup.py install \
    --skip-build \
    --install-purelib %{python_sitearch} \
    --root %{buildroot}
popd

pushd cpp
make install DESTDIR=%{buildroot}/

# clean up items we're not installing
rm -f %{buildroot}/%{_libdir}/libqpidbroker.so
rm -f %{buildroot}/%{_libdir}/libcqpid_perl.so
rm -f %{buildroot}/%{_libdir}/ruby/cqmf2.so
rm -f %{buildroot}/%{_libdir}/ruby/cqpid.so
rm -f %{buildroot}/%{_libdir}/ruby/qmfengine.so
rm -f %{buildroot}/%{ruby_sitelib}
rm -rf %{buildroot}/%{_libdir}/perl5

# delete items not used by the QMF packages
rm -rf %{buildroot}/etc/qpid
rm -rf %{buildroot}/%{_initrddir}
rm -rf %{buildroot}/%{_sysconfdir}/sasl2
rm -rf %{buildroot}/%{_bindir}/qpid*
rm -rf %{buildroot}/%{_sbindir}/qpidd
rm -rf %{buildroot}/%{_includedir}/qpid
rm -rf %{buildroot}/%{_includedir}/qmf
rm -rf %{buildroot}/%{python_sitelib}/qpid
rm -rf %{buildroot}/%{python_sitelib}/qpid_tools*
rm -rf %{buildroot}/%{python_sitearch}/mllib
rm -rf %{buildroot}/%{python_sitearch}/qpid
rm -rf %{buildroot}/%{python_sitearch}/*qpid_messaging*
rm -rf %{buildroot}/%{python_sitelib}/*egg-info
rm -rf %{buildroot}/%{python_sitearch}/*egg-info
rm -rf %{buildroot}/%{_libdir}/libqpid*
rm -rf %{buildroot}/%{_libdir}/librdmawrap*
rm -rf %{buildroot}/%{_libdir}/qpid
rm -rf %{buildroot}/%{_libdir}/pkgconfig/qpid.pc
rm -rf %{buildroot}/%{_pkgdocdir}/api
rm -rf %{buildroot}/%{_mandir}
rm -rf %{buildroot}/%{_datadir}/qpid/examples
rm -rf %{buildroot}/%{_libexecdir}/qpid

popd

# Set executable bit on shared libraries to ensure the binaries are stripped
chmod +x %{buildroot}/%{python_sitearch}/*so

# QMF Python management
install -d %{_builddir}/cpp/managementgen/qmfgen \
           %{buildroot}/%{python_sitelib}

# QMF Ruby package
install -d %{buildroot}%{ruby_vendorlibdir}
install -d %{buildroot}%{ruby_vendorarchdir}
install -pm 644 %{_builddir}/qpid-%{version}/cpp/bindings/qmf2/ruby/qmf2.rb \
    %{buildroot}%{ruby_vendorlibdir}
install -pm 755 %{_builddir}/qpid-%{version}/cpp/bindings/qpid/ruby/cqpid_ruby.so \
     %{buildroot}%{ruby_vendorarchdir}/cqpid.so
install -pm 755 %{_builddir}/qpid-%{version}/cpp/bindings/qmf2/ruby/cqmf2_ruby.so \
    %{buildroot}%{ruby_vendorarchdir}/cqmf2.so

# clean up leftover ruby files
rm -rf %{buildroot}/usr/local/%{_lib}/ruby/site_ruby



%changelog
* Wed Jul  9 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.26-2
- Removed intra-package comments that were pulled into the postun scripts.

* Thu Jun 12 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.26-1
- Rebased on Qpid 0.26.

* Mon Jun  2 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-21
- Missed the arch reference on one requires.

* Mon Jun  2 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-20
- Added arch reference to qpid client requirement.
- Resolves: BZ#1103373

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 0.24-19
- rebuild for boost 1.55.0

* Thu May 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-18
- Changed dependencies on qpid-cpp-client to be qpid(client).

* Mon May  5 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-17
- Fixed FTBFS on F21 due to dead code.

* Tue Apr 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-17
- First release for qpid-cpp repository.
- Support for EL6.

* Mon Feb  3 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-16
- Fix dependencies onto qpid-cpp packages to be >= 0.24.
- Fixed building with -Werror=format-security enabled.

* Thu Oct 31 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-15
- First separate build of QMF packages for Fedora.
- Changed shebangs to use explicit references to interpreters.

* Wed Oct 30 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-14
- Added dependency from qpid-qmf onto python-qpid-qmf.

* Tue Oct 29 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-13
- Removed release portion of Requires.
- QPID-5273: Fixed installation of qmfgen Python library.

* Mon Oct 28 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-12
- Added missing dist tag.
- Added filters for Swig-generated binding libraries.
- Set executable bit on Python libraries to ensure they're stripped.

* Fri Oct 25 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-11
- Removed unused global macros.
- Removed BR for python since it's provided by python-devel.
- Changed BR for python-devel to python2-devel.
- Removed BR for ruby since it's provided by ruby-devel.
- Added project description from the QMF website to qpid-qmf package.
- Made qpid-qmf owner of pkgdocdir.
- Filter out pkgconfig dependency.

* Thu Oct 17 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-10
- Initial attempt at separately packaging the QMF code.
